![PyPI - Version](https://img.shields.io/pypi/v/ttsim-backend)
[![image](https://img.shields.io/conda/vn/conda-forge/ttsim-backend.svg)](https://anaconda.org/conda-forge/ttsim-backend)
[![main](https://github.com/ttsim-dev/ttsim/actions/workflows/main.yaml/badge.svg)](https://github.com/ttsim-dev/ttsim/actions/workflows/main.yaml)
[![image](https://codecov.io/gh/ttsim-dev/ttsim/branch/main/graph/badge.svg)](https://codecov.io/gh/ttsim-dev/ttsim)
[![Ruff](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/ruff/main/assets/badge/v2.json)](https://github.com/astral-sh/ruff)
[![pre-commit.ci status](https://results.pre-commit.ci/badge/github/ttsim-dev/ttsim/main.svg)](https://results.pre-commit.ci/latest/github/ttsim-dev/ttsim/main)
[![image](https://img.shields.io/github/contributors/ttsim-dev/ttsim.svg)](https://github.com/ttsim-dev/ttsim/graphs/contributors)
[![image](https://img.shields.io/badge/License-GPLv3-blue.svg)](https://www.gnu.org/licenses/gpl-3.0)
[![image](https://img.shields.io/badge/zulip-join_chat-brightgreen.svg)](https://gettsim.zulipchat.com)

TTSIM provides the computing engine powering the German Taxes and Transfers Simulator
[GETTSIM](https://github.com/ttsim-dev/gettsim).

The documentation is available at <https://gettsim.readthedocs.io>. If you want to use
it or help out in its development, feel free to get in touch! The ideal ways are to open
an issue if you find a bug or something does not work as expected, or by joining our
Zulip Chat at <https://gettsim.zulipchat.com>.
